tonalitytools.Mode
==================

.. abjad-lineage:: abjad.tools.tonalitytools.Mode.Mode.Mode

.. autoclass:: abjad.tools.tonalitytools.Mode.Mode.Mode
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.Mode.Mode.Mode.melodic_diatonic_interval_segment
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Mode.Mode.Mode.mode_name
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Mode.Mode.Mode.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__ge__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__gt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__le__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__len__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__lt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__repr__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Mode.Mode.Mode.__str__
   :noindex:
